@@ -116,7 +116,7 @@ intifada::Stream::size_type intifada::Block::set_stream(const uint8_t *s, const
   // Check if expected block size exceed message size
   if(block_end_size>m)
     {
-      throw Parsing_Input_Length_Exception(block_end_size,m);
+      throw Parsing_Input_Length_Exception(stream_pos,block_end_size,m);
     }
   while(stream_pos<block_end_size)
     {
