@@ -28,6 +28,7 @@ intifada::Configuration_Internal_Reader::Configuration_Internal_Reader(const std
   ,cmds_()
   ,args_()
   ,last_call_status_(true)
+  ,parser_()
   {}
 intifada::Configuration_Internal_Reader::~Configuration_Internal_Reader()
   {this->release();}
@@ -39,23 +40,14 @@ int intifada::Configuration_Internal_Reader::open()
     while(file)
       {
         opened=0;
-        char line[255];
-        file.getline(line,255);
-        std::string l=line;
-        std::string::size_type seppos=l.find_first_of(':');
-
-        if(seppos!=std::string::npos)
-          {
-            std::string cmd=l.substr(0,seppos);
-            std::string arg;
-            if(seppos < l.size())
-              {
-                arg=l.substr(seppos+1);
-              }
-            cmds_.push_back(std::make_pair(cmd,arg));
-          }
-
-
+        parser_.parse(file);
+        const std::string& key=parser_.get_key();
+        std::string arg;
+        parser_.get_arg(arg);
+        if(key.empty()!=true)
+        {
+          cmds_.push_back(std::make_pair(key,arg));
+        }
       }
     return opened;
   }
