@@ -17,6 +17,8 @@
  */
 
 #include <intifada/Dynamic_Loader.hxx>
+
+#if 0
 #include <errno.h>
 
 intifada::Dynamic_Loader::Dynamic_Loader():
@@ -55,3 +57,4 @@ intifada::Dynamic_Loader::open(const std::string& n)
 
   return 0;
 }
+#endif
