@@ -51,61 +51,71 @@ intifada::Parsing_Exception::Parsing_Exception(){}
 intifada::Parsing_Exception::~Parsing_Exception(){}
 
 intifada::Parsing_Unknow_Category::Parsing_Unknow_Category(const std::string& family,const uint8_t& c):
-  family_(family),category_(c){}
+      family_(family),category_(c){}
 
 const std::string& intifada::Parsing_Unknow_Category::get_family()const
-{
+    {
   return family_;
-}
+    }
 
 const uint8_t& intifada::Parsing_Unknow_Category::get_category()const
-{
+    {
   return category_;
-}
+    }
 
 intifada::Parsing_Input_Length_Exception::Parsing_Input_Length_Exception(int waited,int received):
-  inherited(waited,received)
-{}
+      inherited(waited,received)
+      {}
+
+intifada::Parsing_Input_Length_Exception::Parsing_Input_Length_Exception(int error_pos,int waited,int received):
+      inherited(error_pos,waited,received)
+      {}
 
 intifada::Parsing_Input_Record_Length_Exception::Parsing_Input_Record_Length_Exception(const Path_Name& n,int received):
-  inherited(-1,received),
-  name_(n)
-{}
+      inherited(-1,received),
+      name_(n)
+      {}
 const intifada::Path_Name& intifada::Parsing_Input_Record_Length_Exception::get_name()const
-{
+    {
   return name_;
-}
+    }
 
 intifada::Parsing_Input_Field_Specification_Exception::Parsing_Input_Field_Specification_Exception(int waited,int received):
-  inherited(waited,received)
-{}
+      inherited(waited,received)
+      {}
 
-intifada::Parsing_Length_Exception::Parsing_Length_Exception(int waited,int received):
-  w_(waited)
-  ,r_(received)
-{}
+intifada::Parsing_Stream_Exception::Parsing_Stream_Exception(int error_pos,int expected,int received):
+        error_pos_(error_pos)
+        ,w_(expected)
+        ,r_(received)
+        {}
+intifada::Parsing_Stream_Exception::Parsing_Stream_Exception(int expected,int received):
+        error_pos_(-1)
+        ,w_(expected)
+        ,r_(received)
+        {}
 
 intifada::Parsing_Output_Length_Exception::Parsing_Output_Length_Exception(int waited,int received):
-  inherited(waited,received)
-{}
+      inherited(waited,received)
+      {}
 
 intifada::Parsing_XML_Exception::Parsing_XML_Exception(){}
 
 intifada::Parsing_XML_Family_Duplicate_Exception::Parsing_XML_Family_Duplicate_Exception(const std::string& family):family_(family){}
 
 std::string intifada::Parsing_XML_Family_Duplicate_Exception::what()const
-{
+    {
   return "Parsing_XML_Family_Duplicate_Exception:"+family_+" duplicate";
-}
+    }
 
 std::string intifada::Parsing_XML_Family_Duplicate_Exception::get_family()const
-{
+    {
   return family_;
-}
+    }
 
 intifada::Parsing_XML_Dynamic_Type_Exception::Parsing_XML_Dynamic_Type_Exception(const std::string& type_error):type_error_(type_error){}
 
 std::string intifada::Parsing_XML_Dynamic_Type_Exception::what()const
-{
+    {
   return "Parsing_XML_Dynamic_Type_Exception:"+type_error_;
-}
+    }
