@@ -457,20 +457,6 @@ throw(Description_Field_Unknow_Exception){
   }
 }
 
-#if 0
-const intifada::Type& intifada::Record::operator()(const Path_Name& name)const
-{
-  const Type*pret=this->get_value(name);
-  return *pret;
-}
-
-intifada::Type& intifada::Record::operator()(const Path_Name& name)
-{
-  Type*pret=this->get_value(name);
-  return *pret;
-}
-#endif
-
 const intifada::Type& intifada::Record::get_value(const Path_Name& name)const
 {
   clog("Record") << "get_value(" << name << ")-->" << cendl;
@@ -523,30 +509,6 @@ intifada::Type& intifada::Record::get_value(const Path_Name& name)
   return *ret;
 }
 
-#if 0
-void intifada::Record::get_value(const Path_Name& name, intifada::Type& ret)const
-{
-  const Type *t=this->get_value(name);
-    ret=*t;
-    return;
-}
-
-void intifada::Record::set_value(const Path_Name& name,const intifada::Type& ret)
-  {
-    clog("Record") << "set_value(" << name << ")" << cendl;
-    Path_Name subpart=name;
-    std::string part=name.get_front();
-    subpart.pop_front();
-    Data_Field *df=get_subfield(part);
-
-    if(df != NULL){
-      df->set_value(subpart,ret);
-    }else{
-      throw Description_Field_Unknow_Exception(name);
-    }
-  }
-#endif
-
 intifada::Data_Field* intifada::Record::clone()const
 {
   // create a record
@@ -596,13 +558,6 @@ intifada::Record::foreach(Const_Functor &it,const Path_Name& sel)const
   return ret;
 }
 
-int
-intifada::Record::get_structure()const
-{
-  fspec_.get_structure();
-  return 0;
-}
-
 int
 intifada::Record::foreach_structure(Structure_Functor *f)const
 {
